methodChannel property
The method channel used to talk to Android and iOS.
Implementation
@visibleForTesting
final MethodChannel methodChannel = const MethodChannel('wifi_configuration');
The method channel used to talk to Android and iOS.
@visibleForTesting
final MethodChannel methodChannel = const MethodChannel('wifi_configuration');