MethodChannelWifiConfiguration class
Method-channel implementation of WifiConfigurationPlatform.
- Inheritance
-
- Object
- PlatformInterface
- WifiConfigurationPlatform
- MethodChannelWifiConfiguration
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to talk to Android and iOS.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
connectedToWifi(
) → Future< String> -
Current SSID, or empty when unknown.
override
-
connectToWifi(
{required String ssid, required String password, String? packageName}) → Future< String> -
Connects to
ssid. Returns a WifiConnectionStatus name.override -
getPlatformVersion(
) → Future< String?> -
OS version string from the host platform.
override
-
getWifiList(
) → Future< List< String> > -
Nearby or configured Wi-Fi SSIDs.
override
-
isConnectedToWifi(
String ssid) → Future< bool> -
Whether the current SSID matches
ssid.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited