WifiConfigurationPlatform class abstract
The interface that implementations of wifi_configuration must implement.
- Inheritance
-
- Object
- PlatformInterface
- WifiConfigurationPlatform
- Implementers
Constructors
- WifiConfigurationPlatform()
- Constructs a WifiConfigurationPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
connectedToWifi(
) → Future< String> - Current SSID, or empty when unknown.
-
connectToWifi(
{required String ssid, required String password, String? packageName}) → Future< String> -
Connects to
ssid. Returns a WifiConnectionStatus name. -
getPlatformVersion(
) → Future< String?> - OS version string from the host platform.
-
getWifiList(
) → Future< List< String> > - Nearby or configured Wi-Fi SSIDs.
-
isConnectedToWifi(
String ssid) → Future< bool> -
Whether the current SSID matches
ssid. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ WifiConfigurationPlatform
-
The default instance of WifiConfigurationPlatform to use.
getter/setter pair